# [`egg-smol`](https://github.com/mwillsey/egg-smol/) Python

`egg-smol` is a Python package that provides bindings to the Rust library `egg-smol`,
allowing you to use e-graphs in Python for optimization, symbolic computation, and analysis.

```shell
pip install egg-smol
```

```{toctree}
auto_examples/index
tutorials
how-to-guides
explanation
reference
```
